pitchtools.chromatic_pitch_name_to_diatonic_pitch_name
======================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_name_to_diatonic_pitch_name.chromatic_pitch_name_to_diatonic_pitch_name
